@@ -14,6 +14,7 @@ const shared = require('../shared');
 const CONNECTION_TIMEOUT = 2 * 60 * 1000; // how much to wait for the connection to be established
 const SOCKET_TIMEOUT = 10 * 60 * 1000; // how much to wait for socket inactivity before disconnecting the client
 const GREETING_TIMEOUT = 30 * 1000; // how much to wait after connection is established but SMTP greeting is not receieved
+const DNS_TIMEOUT = 30 * 1000; // how much to wait for resolveHostname
 
 /**
  * Generates a SMTP connection object
@@ -30,6 +31,7 @@ const GREETING_TIMEOUT = 30 * 1000; // how much to wait after connection is esta
  *  * **greetingTimeout** - Time to wait in ms until greeting message is received from the server (defaults to 10000)
  *  * **connectionTimeout** - how many milliseconds to wait for the connection to establish
  *  * **socketTimeout** - Time of inactivity until the connection is closed (defaults to 1 hour)
+ *  * **dnsTimeout** - Time to wait in ms for the DNS requests to be resolved (defaults to 30 seconds)
  *  * **lmtp** - if true, uses LMTP instead of SMTP protocol
  *  * **logger** - bunyan compatible logger interface
  *  * **debug** - if true pass SMTP traffic to the logger
@@ -56,6 +58,8 @@ class SMTPConnection extends EventEmitter {
         this.port = Number(this.options.port) || (this.secureConnection ? 465 : 587);
         this.host = this.options.host || 'localhost';
 
+        this.allowInternalNetworkInterfaces = this.options.allowInternalNetworkInterfaces || false;
+
         if (typeof this.options.secure === 'undefined' && this.port === 465) {
             // if secure option is not set but port is 465, then default to secure
             this.secureConnection = true;
@@ -217,7 +221,9 @@ class SMTPConnection extends EventEmitter {
 
         let opts = {
             port: this.port,
-            host: this.host
+            host: this.host,
+            allowInternalNetworkInterfaces: this.allowInternalNetworkInterfaces,
+            timeout: this.options.dnsTimeout || DNS_TIMEOUT
         };
 
         if (this.options.localAddress) {
@@ -811,6 +817,20 @@ class SMTPConnection extends EventEmitter {
      * @event
      */
     _onClose() {
+        let serverResponse = false;
+
+        if (this._remainder && this._remainder.trim()) {
+            if (this.options.debug || this.options.transactionLog) {
+                this.logger.debug(
+                    {
+                        tnx: 'server'
+                    },
+                    this._remainder.replace(/\r?\n$/, '')
+                );
+            }
+            this.lastServerResponse = serverResponse = this._remainder.trim();
+        }
+
         this.logger.info(
             {
                 tnx: 'network'
@@ -819,9 +839,11 @@ class SMTPConnection extends EventEmitter {
         );
 
         if (this.upgrading && !this._destroyed) {
-            return this._onError(new Error('Connection closed unexpectedly'), 'ETLS', false, 'CONN');
+            return this._onError(new Error('Connection closed unexpectedly'), 'ETLS', serverResponse, 'CONN');
         } else if (![this._actionGreeting, this.close].includes(this._responseActions[0]) && !this._destroyed) {
-            return this._onError(new Error('Connection closed unexpectedly'), 'ECONNECTION', false, 'CONN');
+            return this._onError(new Error('Connection closed unexpectedly'), 'ECONNECTION', serverResponse, 'CONN');
+        } else if (/^[45]\d{2}\b/.test(serverResponse)) {
+            return this._onError(new Error('Connection closed unexpectedly'), 'ECONNECTION', serverResponse, 'CONN');
         }
 
         this._destroy();
@@ -938,14 +960,14 @@ class SMTPConnection extends EventEmitter {
 
         if (!str.trim()) {
             // skip unexpected empty lines
-            setImmediate(() => this._processResponse(true));
+            setImmediate(() => this._processResponse());
         }
 
         let action = this._responseActions.shift();
 
         if (typeof action === 'function') {
             action.call(this, str);
-            setImmediate(() => this._processResponse(true));
+            setImmediate(() => this._processResponse());
         } else {
             return this._onError(new Error('Unexpected Response'), 'EPROTOCOL', str, 'CONN');
         }
@@ -1108,7 +1130,7 @@ class SMTPConnection extends EventEmitter {
             notify = notify.join(',');
         }
 
-        let orcpt = (params.orcpt || params.recipient || '').toString() || null;
+        let orcpt = (params.recipient || params.orcpt || '').toString() || null;
         if (orcpt && orcpt.indexOf(';') < 0) {
             orcpt = 'rfc822;' + orcpt;
         }
@@ -1258,6 +1280,12 @@ class SMTPConnection extends EventEmitter {
             return;
         }
 
+        this._ehloLines = str
+            .split(/\r?\n/)
+            .map(line => line.replace(/^\d+[ -]/, '').trim())
+            .filter(line => line)
+            .slice(1);
+
         // Detect if the server supports STARTTLS
         if (!this.secure && !this.options.ignoreTLS && (/[ -]STARTTLS\b/im.test(str) || this.options.requireTLS)) {
             this._sendCommand('STARTTLS');
@@ -1655,6 +1683,10 @@ class SMTPConnection extends EventEmitter {
             rejected: this._envelope.rejected
         };
 
+        if (this._ehloLines && this._ehloLines.length) {
+            response.ehlo = this._ehloLines;
+        }
+
         if (this._envelope.rejectedErrors.length) {
             response.rejectedErrors = this._envelope.rejectedErrors;
         }
@@ -1755,10 +1787,16 @@ class SMTPConnection extends EventEmitter {
 
     _getHostname() {
         // defaul hostname is machine hostname or [IP]
-        let defaultHostname = os.hostname() || '';
+        let defaultHostname;
+        try {
+            defaultHostname = os.hostname() || '';
+        } catch (err) {
+            // fails on windows 7
+            defaultHostname = 'localhost';
+        }
 
         // ignore if not FQDN
-        if (defaultHostname.indexOf('.') < 0) {
+        if (!defaultHostname || defaultHostname.indexOf('.') < 0) {
             defaultHostname = '[127.0.0.1]';
         }
 
