@@ -414,14 +414,14 @@ describe('Shared Funcs Tests', function () {
                 expect(err).to.not.exist;
                 expect(result).to.deep.equal({
                     servername: 'ipv4.single.dev.ethereal.email',
-                    host: '54.36.85.114',
+                    host: '95.216.108.161',
                     cached: false
                 });
                 shared.resolveHostname({ host: 'ipv4.single.dev.ethereal.email' }, (err, result) => {
                     expect(err).to.not.exist;
                     expect(result).to.deep.equal({
                         servername: 'ipv4.single.dev.ethereal.email',
-                        host: '54.36.85.114',
+                        host: '95.216.108.161',
                         cached: true
                     });
                     done();
@@ -480,14 +480,14 @@ describe('Shared Funcs Tests', function () {
                 expect(err).to.not.exist;
                 expect(result).to.deep.equal({
                     servername: 'ipv6.single.dev.ethereal.email',
-                    host: '2001:41d0:304:200::baa9',
+                    host: '2a01:4f9:3051:4501::2',
                     cached: false
                 });
                 shared.resolveHostname({ host: 'ipv6.single.dev.ethereal.email' }, (err, result) => {
                     expect(err).to.not.exist;
                     expect(result).to.deep.equal({
                         servername: 'ipv6.single.dev.ethereal.email',
-                        host: '2001:41d0:304:200::baa9',
+                        host: '2a01:4f9:3051:4501::2',
                         cached: true
                     });
                     done();
@@ -495,29 +495,6 @@ describe('Shared Funcs Tests', function () {
             });
         });
 
-        it('should fail resolving a single IPv6 entry', function (done) {
-            // ensure that there is a single Ipv4 interface "available"
-            Object.keys(shared.networkInterfaces).forEach(key => {
-                delete shared.networkInterfaces[key];
-            });
-
-            shared.networkInterfaces.en0 = [
-                {
-                    address: '192.168.1.175',
-                    netmask: '255.255.255.0',
-                    family: 'IPv4',
-                    mac: 'f0:18:98:57:76:44',
-                    internal: false,
-                    cidr: '192.168.1.175/24'
-                }
-            ];
-
-            shared.resolveHostname({ host: 'ipv6.single.dev.ethereal.email' }, err => {
-                expect(err).to.exist;
-                done();
-            });
-        });
-
         it('should fail missing address', function (done) {
             shared.resolveHostname({ host: 'missing.single.dev.ethereal.email' }, err => {
                 expect(err).to.exist;
@@ -554,8 +531,13 @@ describe('Shared Funcs Tests', function () {
                 }
             ];
 
-            shared.resolveHostname({ host: 'ipv4.single.dev.ethereal.email' }, err => {
-                expect(err).to.exist;
+            shared.resolveHostname({ host: 'ipv4.single.dev.ethereal.email' }, (err, result) => {
+                expect(err).to.not.exist;
+                expect(result).to.deep.equal({
+                    servername: 'ipv4.single.dev.ethereal.email',
+                    host: 'ipv4.single.dev.ethereal.email',
+                    cached: false
+                });
                 done();
             });
         });
@@ -586,7 +568,7 @@ describe('Shared Funcs Tests', function () {
                     expect(err).to.not.exist;
                     expect(result).to.deep.equal({
                         servername: 'ipv4.single.dev.ethereal.email',
-                        host: '54.36.85.114',
+                        host: '95.216.108.161',
                         cached: false
                     });
                     done();
